import { ITerminal, ITerminalSize } from '../common/types.ts';

const DenoTerminalIO: ITerminal = {
	argv: Deno.args,
	/**
	 * Wrap the runtime-specific hook into stdin
	 */
	inputLoop: async function* inputLoop() {
		for await (const chunk of Deno.stdin.readable) {
			yield chunk;
		}
	},
	getTerminalSize: function getSize(): Promise<ITerminalSize> {
		const size: { rows: number; columns: number } = Deno.consoleSize();

		return Promise.resolve({
			rows: size.rows,
			cols: size.columns,
		});
	},
	writeStdout: async function write(s: string): Promise<void> {
		const buffer: Uint8Array = new TextEncoder().encode(s);
		const stdout: WritableStream<Uint8Array> = Deno.stdout.writable;

		const writer: WritableStreamDefaultWriter<Uint8Array> = stdout.getWriter();
		await writer.ready;
		await writer.write(buffer);
		writer.releaseLock();
	},
};

export default DenoTerminalIO;
